@@ -1,5 +1,5 @@
 package Util::Medley::XML;
-$Util::Medley::XML::VERSION = '0.055';
+$Util::Medley::XML::VERSION = '0.056';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -16,7 +16,7 @@ Util::Medley::XML - utility XML methods
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =cut
 
@@ -35,11 +35,18 @@ error.
 
 =cut
 
+has _xmlLintExists => (
+    is => 'ro',
+    isa => 'Bool',
+    lazy => 1,
+    builder => '_buildXmlLintExists',
+);
+
 ########################################################
 
 =head1 METHODS
 
-=head2 xmlBeautifyFile
+=head2 beautifyFile
 
 Beautifies an XML file.  Requires the xmllint command.
 
@@ -47,9 +54,9 @@ Beautifies an XML file.  Requires the xmllint command.
 
 =item usage:
 
- $util->xmlBeautifyFile($path);
+ $util->beautifyFile($path);
 
- $util->xmlBeautifyFile(path => $path);
+ $util->beautifyFile(path => $path);
  
 =item args:
 
@@ -65,19 +72,35 @@ Location of the xml file.
 
 =cut
 
-multi method xmlBeautifyFile (Str :$path!) {
+multi method beautifyFile (Str :$path!) {
 
+    if (!$self->_xmlLintExists) {
+        confess "unable to find xmllint cmd";
+    }
+    
 	my $cmd = "xmllint --format $path > $path.tmp";
 	$self->Spawn->spawn( cmd => $cmd );
 	$self->File->mv( "$path.tmp", $path );
 }
 
-multi method xmlBeautifyFile (Str $path) {
+multi method beautifyFile (Str $path) {
 
 	$self->xmllBeautifyFile(path => $path);
 }
 
-=head2 xmlBeautifyString
+# deprecated method
+multi method xmlBeautifyFile (Str :$path!) {
+   
+    return $self->beautifyFile(@_);
+}
+
+# deprecated method
+multi method xmlBeautifyFile (Str $path) {
+    
+    return $self->beautifyFile(@_);
+}
+
+=head2 beautifyString
 
 Formats an XML string.  Requires the xmllint command.
 
@@ -85,7 +108,7 @@ Formats an XML string.  Requires the xmllint command.
 
 =item usage:
 
- $util->xmlBeautifyString($xml);
+ $util->beautifyString($xml);
 
  $util->XmlBeautifyString(xml => $xml);
  
@@ -103,8 +126,12 @@ An XML string.
 
 =cut
 
-multi method xmlBeautifyString (Str :$xml!) {
+multi method beautifyString (Str :$xml!) {
 
+    if (!$self->_xmlLintExists) {
+        confess "unable to find xmllint cmd";
+    }
+    
 	my @cmd = ( 'xmllint', '--format', '-' );
 	my ( $stdout, $stderr, $exit ) =
 	  $self->Spawn->capture( cmd => \@cmd, stdin => $xml );
@@ -112,11 +139,33 @@ multi method xmlBeautifyString (Str :$xml!) {
 	return $stdout;
 }
 
-multi method xmlBeautifyString (Str $xml) {
+multi method beautifyString (Str $xml) {
 
-	return $self->xmlBeautifyString(xml => $xml);
+	return $self->beautifyString(xml => $xml);
+}
+           
+# deprecated method            
+multi method xmlBeautifyString (Str :$xml!) {
+    
+    return $self->beautifyString(@_); 
+}
+
+# deprecated method
+multi method xmlBeautifyString (Str $xml) {
+    
+    return $self->beautifyString(@_);
 }
                 	  
 ######################################################################
 
+method _buildXmlLintExists {
+
+    my $path = $self->File->which('xmllint');        
+    if ($path) {
+        return 1;    
+    }    
+    
+    return 0;
+}
+
 1;
